@@ -18,5 +18,5 @@ along with CVXPY.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from constant import Constant
-from constant_atom import ConstantAtom
-from parameter import Parameter
\ No newline at end of file
+from callback_param import CallbackParam
+from parameter import Parameter
