@@ -55,10 +55,20 @@ class Parameter(Constant):
     def value(self):
         return self._value
 
-    @value.setter
-    def value(self, val):
+    def _validate_value(self, val):
+        """Check that the value satisfies the parameter's symbolic attributes.
+
+        Parameters
+        ----------
+        val : numeric type
+            The value assigned.
+
+        Returns
+        -------
+        numeric type
+            The value converted to the proper matrix type.
+        """
         # Convert val to the proper matrix type.
-        intf.warn_1D_array(val)
         val = intf.DEFAULT_INTERFACE.const_to_matrix(val)
         size = intf.size(val)
         if size != self.size:
@@ -71,7 +81,11 @@ class Parameter(Constant):
         if self.is_positive() and not sign.is_positive() or \
            self.is_negative() and not sign.is_negative():
             raise ValueError("Invalid sign for Parameter value.")
-        self._value = val
+        return val
+
+    @value.setter
+    def value(self, val):
+        self._value = self._validate_value(val)
 
     def parameters(self):
         """Returns itself as a parameter.
