@@ -38,6 +38,9 @@ DEFAULT_NP_INTERFACE = INTERFACES[np.ndarray]
 # Default dense and sparse matrix interfaces.
 DEFAULT_INTERFACE = INTERFACES[np.matrix]
 DEFAULT_SPARSE_INTERFACE = INTERFACES[sp.csc_matrix]
+# CVXOPT interfaces.
+CVXOPT_DENSE_INTF = INTERFACES[cvxopt.matrix]
+CVXOPT_SPARSE_INTF = INTERFACES[cvxopt.spmatrix]
 
 # Returns the interface for interacting with the target matrix class.
 def get_matrix_interface(target_class):
@@ -48,12 +51,6 @@ def is_sparse(constant):
     """
     return sp.issparse(constant) or isinstance(constant, cvxopt.spmatrix)
 
-def warn_1D_array(constant):
-    """Raises a warning for NumPy 1D arrays.
-    """
-    if isinstance(constant, np.ndarray) and constant.ndim == 1:
-        warnings.warn("NumPy 1D arrays are treated as column vectors.")
-
 # Get the dimensions of the constant.
 def size(constant):
     if isinstance(constant, numbers.Number):
@@ -84,12 +81,15 @@ def is_scalar(constant):
 def from_2D_to_1D(constant):
     """Convert 2D Numpy matrices or arrays to 1D.
     """
-    return np.asarray(constant)[:, 0]
+    if isinstance(constant, np.ndarray):
+        return np.asarray(constant)[:, 0]
+    else:
+        return constant
 
 def from_1D_to_2D(constant):
     """Convert 1D Numpy arrays to matrices.
     """
-    if constant.ndim == 1:
+    if isinstance(constant, np.ndarray) and constant.ndim == 1:
         return np.mat(constant).T
     else:
         return constant
