@@ -23,6 +23,8 @@ from cvxpy.expressions.constants import Constant, Parameter
 from cvxpy.expressions.variables import Variable, Semidef
 from cvxpy.problems.objective import *
 from cvxpy.problems.problem import Problem
+from cvxpy.problems.solvers.utilities import SOLVERS
+from cvxpy.problems.problem_data.sym_data import SymData
 import cvxpy.interface as intf
 import cvxpy.lin_ops.lin_utils as lu
 from base_test import BaseTest
@@ -88,10 +90,6 @@ class TestProblem(BaseTest):
             Problem(Maximize(exp(self.a))).get_problem_data(s.ECOS)
         self.assertEqual(str(cm.exception), "The solver ECOS cannot solve the problem.")
 
-        with self.assertRaises(Exception) as cm:
-            Problem(Maximize(exp(self.a))).get_problem_data(s.CVXOPT)
-        self.assertEqual(str(cm.exception), "Cannot return problem data for the solver CVXOPT.")
-
         args = Problem(Maximize(exp(self.a) + 2)).get_problem_data(s.SCS)
         data, dims = args
         self.assertEqual(dims['ep'], 1)
@@ -178,14 +176,14 @@ class TestProblem(BaseTest):
             var_ids_order_created.append(var_ids)
             obj = Minimize(sum)
             p = Problem(obj, constraints)
-            objective, constr_map = p.canonicalize()
-            all_ineq = itertools.chain(constr_map[s.EQ], constr_map[s.LEQ])
-            var_offsets, var_sizes, x_length = p._get_var_offsets(objective, all_ineq)
+            objective, constraints = p.canonicalize()
+            sym_data = SymData(objective, constraints, SOLVERS[s.ECOS])
             # Sort by offset.
-            vars_ = sorted(var_offsets.items(), key=lambda (var_id, offset): offset)
+            vars_ = sorted(sym_data.var_offsets.items(),
+                key=lambda (var_id, offset): offset)
             vars_ = [var_id for (var_id, offset) in vars_]
             vars_lists.append(vars_)
-            ineqs_lists.append(constr_map[s.LEQ])
+            ineqs_lists.append(sym_data.constr_map[s.LEQ])
 
         # Verify order of variables is consistent.
         for i in range(num_solves):
@@ -203,22 +201,21 @@ class TestProblem(BaseTest):
         le = (self.x <= 2)
         obj = 0
         def test(self):
-            objective, constr_map  = self.canonicalize()
-            self._presolve(objective, constr_map)
-            print len(constr_map[s.SOC])
-            dims = self._format_for_solver(constr_map, s.ECOS)
-            return (len(constr_map[s.EQ]),len(constr_map[s.LEQ]))
+            objective, constraints = self.canonicalize()
+            sym_data = SymData(objective, constraints, SOLVERS[s.ECOS])
+            return (len(sym_data.constr_map[s.EQ]),
+                    len(sym_data.constr_map[s.LEQ]))
         Problem.register_solve("test", test)
         p = Problem(Minimize(obj),[eq,eq,le,le])
         result = p.solve(method="test")
         self.assertEqual(result, (1, 1))
 
         # Internal constraints.
-        z = hstack(self.x, self.x)
-        obj = sum_entries(z[:,0] + z[:,1])
+        X = Semidef(2)
+        obj = sum_entries(X + X)
         p = Problem(Minimize(obj))
         result = p.solve(method="test")
-        self.assertEqual(result, (2, 0))
+        self.assertEqual(result, (1, 1))
 
         # Duplicates from non-linear constraints.
         exp = norm(self.x, 2)
@@ -367,7 +364,7 @@ class TestProblem(BaseTest):
         assert (self.A.value >= T*self.C.value).all()
 
         # Test variables are dense.
-        self.assertEqual(type(self.A.value), p._DENSE_INTF.TARGET_MATRIX)
+        self.assertEqual(type(self.A.value), intf.DEFAULT_INTERFACE.TARGET_MATRIX)
 
     # Test variable promotion.
     def test_variable_promotion(self):
@@ -723,12 +720,13 @@ class TestProblem(BaseTest):
         result = p.solve()
         self.assertAlmostEqual(result, -4)
 
-        c = matrix(1, (1,2))
-        p = Problem( Minimize( sum_entries(hstack(c*self.A, c*self.B)) ),
-            [self.A >= 2,
-            self.B == -2])
+        D = Variable(3, 3)
+        expr = hstack(self.C, D)
+        p = Problem( Minimize( expr[0,1] + sum_entries(hstack(expr, expr)) ),
+            [self.C >= 0,
+             D >= 0, D[0,0] == 2, self.C[0,1] == 3])
         result = p.solve()
-        self.assertAlmostEqual(result, 0)
+        self.assertAlmostEqual(result, 13)
 
         c = matrix([1,-1])
         p = Problem( Minimize( c.T * hstack(square(self.a).T, sqrt(self.b).T).T),
@@ -1040,3 +1038,19 @@ class TestProblem(BaseTest):
             assert A[row, :].nnz > 0
         for row in range(G.shape[0]):
             assert G[row, :].nnz > 0
+
+    def test_presolve_parameters(self):
+        """Test presolve with parameters.
+        """
+        # Test with parameters.
+        gamma = Parameter(sign="positive")
+        x = Variable()
+        obj = Minimize(x)
+        prob = Problem(obj, [gamma == 1, x >= 0])
+        gamma.value = 0
+        prob.solve(solver=s.SCS)
+        self.assertEqual(prob.status, s.INFEASIBLE)
+
+        gamma.value = 1
+        prob.solve(solver=s.CVXOPT)
+        self.assertEqual(prob.status, s.OPTIMAL)
